ELBO_conv_HMM_stat_dir: C++ function for updating the ELBO convergence function in a...

View source: R/RcppExports.R

ELBO_conv_HMM_stat_dirR Documentation

C++ function for updating the ELBO convergence function in a static binary directed network.

Description

The C++ function ELBO_conv_HMM_stat_dir() updates the ELBO convergence function when the number of clusters is greater than or equal to 2 in a static binary directed network.

Usage

ELBO_conv_HMM_stat_dir(gamma, alpha, theta, network, N, K)

Arguments

gamma

Vector of current gamma (variational parameters) values.

alpha

Vector of current alpha values.

theta

Vector of current theta (network canonical parameters) values.

network

Array of a network adjacency matrices.

N

Number of nodes.

K

Number of clusters.

Value

Returns the value of ELBO for calculating relative error from the previous iterate that is subsequently used in the stopping criteria of the algorithm.


ergmclust documentation built on March 16, 2026, 5:06 p.m.