ELBO_conv_HMM_stat_undir_K1: C++ function for updating the ELBO convergence function.

View source: R/RcppExports.R

ELBO_conv_HMM_stat_undir_K1R Documentation

C++ function for updating the ELBO convergence function.

Description

The C++ function ELBO_conv_HMM_stat_undir() updates the ELBO convergence function when the number of cluster is equal to 1 in a static binary undirected network.

Usage

ELBO_conv_HMM_stat_undir_K1(theta, network, N)

Arguments

theta

Vector of current theta (network canonical parameters) values.

network

Array of a network adjacency matrices.

N

Number of nodes.

Value

Returns the value of ELBO for calculating relative error from the previous iterate that is subsequently used in the stopping criteria of the algorithm.


ergmclust documentation built on March 16, 2026, 5:06 p.m.