ELBO_conv_weighted_stat_undir: C++ function for updating the ELBO convergence function in a...

View source: R/RcppExports.R

ELBO_conv_weighted_stat_undirR Documentation

C++ function for updating the ELBO convergence function in a weighted static binary undirected network.

Description

The C++ function ELBO_conv_weighted_stat_undir() updates the ELBO convergence function when the number of clusters is greater than or equal to 2 in a weighted static binary undirected network.

Usage

ELBO_conv_weighted_stat_undir(gamma, pi, theta, block_dens_mat, adjmat, N, K)

Arguments

gamma

Vector of current gamma (variational parameters) values.

pi

Vector of current pi (mixture proportions) values.

theta

Vector of current theta (network canonical parameters) values.

block_dens_mat

Array of a network block density matrices.

adjmat

Array of a network adjacency matrices.

N

Number of nodes.

K

Number of clusters.

Value

Returns the value of ELBO for calculating relative error from the previous iterate that is subsequently used in the stopping criteria of the algorithm.


ergmclust documentation built on March 16, 2026, 5:06 p.m.