colsum_Mat_new: C++ function for column-wise numeric calculation in a matrix...

View source: R/RcppExports.R

colsum_Mat_newR Documentation

C++ function for column-wise numeric calculation in a matrix for a weighted static binary undirected network.

Description

The C++ function colsum_Mat_new() calculates the sum of each column in a matrix in a weighted static binary undirected network.

Usage

colsum_Mat_new(M)

Arguments

M

A matrix of numeric type.

Value

Returns a vector as the sum of each column in the input matrix.


ergmclust documentation built on March 16, 2026, 5:06 p.m.