epan: A C++ function for numeric calculation of float format.

View source: R/RcppExports.R

epanR Documentation

A C++ function for numeric calculation of float format.

Description

The C++ function epan() does numeric calculation depending on the absolute value of the input. If the absolute value of the input is less than or equal to 1, a numeric output is returned. Otherwise, 0 is returned.

Usage

epan(input)

Arguments

input

A numeric input of float type.

Value

Returns a float output vector as 0.75*(1-input^2) if the absolute value of the input is less than or equal to 1; 0 otherwise.


ergmclust documentation built on March 16, 2026, 5:06 p.m.