grad_theta_weighted_stat_undir: C++ function for updating the gradient function in a weighted...

View source: R/RcppExports.R

grad_theta_weighted_stat_undirR Documentation

C++ function for updating the gradient function in a weighted static binary undirected network.

Description

The C++ function grad_theta_weighted_stat_undir() updates the gradient function when the number of clusters is greater than or equal to 2 in a weighted static binary undirected network.

Usage

grad_theta_weighted_stat_undir(theta, gamma, adjmat, N, K)

Arguments

theta

Vector of current theta (network canonical parameters) values.

gamma

Vector of current gamma (variational parameters) values.

adjmat

Array of a network adjacency matrices.

N

Number of nodes.

K

Number of clusters.

Value

Returns the gradient vector of ELBO with respect to theta parameters for Newton-Raphson update in the M-step.

Author(s)

Authors: Amal Agarwal, Lingzhou Xue

Maintainer: Yinqi Zhang <ybz5148@psu.edu>


ergmclust documentation built on March 16, 2026, 5:06 p.m.