grad_theta_weighted_stat_undir_K1: C++ function for updating the gradient function in a weighted...

View source: R/RcppExports.R

grad_theta_weighted_stat_undir_K1R Documentation

C++ function for updating the gradient function in a weighted static binary undirected network.

Description

The C++ function grad_HMM_stat_undir() updates the gradient function when the number of clusters is 1 in a weighted static binary undirected network.

Usage

grad_theta_weighted_stat_undir_K1(theta, adjmat, N)

Arguments

theta

Vector of current theta (network canonical parameters) values.

adjmat

Array of a network adjacency matrices.

N

Number of nodes.

Value

Returns the gradient vector of ELBO with respect to theta parameters for Newton-Raphson update in the M-step.


ergmclust documentation built on March 16, 2026, 5:06 p.m.