hess_HMM_stat_dir_re: C++ function for updating the Hessian matrix in a static...

View source: R/RcppExports.R

hess_HMM_stat_dir_reR Documentation

C++ function for updating the Hessian matrix in a static binary directed network.

Description

The C++ function hess_HMM_stat_dir_re() updates the Hessian matrix when the number of clusters is greater than or equal to 2 in a static binary directed network. (The above description may need further improvement.)

Usage

hess_HMM_stat_dir_re(theta, gamma, N, K)

Arguments

theta

Vector of current theta (network canonical parameters) values.

gamma

Vector of current gamma (variational parameters) values.

N

Number of nodes.

K

Number of clusters.

Value

Returns the Hessian matrix of ELBO with respect to theta parameters for Newton-Raphson update in M-step.


ergmclust documentation built on March 16, 2026, 5:06 p.m.