hess_theta_weighted_stat_undir: C++ function for updating the Hessian matrix in a weighted...

View source: R/RcppExports.R

hess_theta_weighted_stat_undirR Documentation

C++ function for updating the Hessian matrix in a weighted static binary undirected network.

Description

The C++ function hess_theta_weighted_stat_undir() updates the Hessian matrix when the number of clusters is greater than or equal to 2 in a weighted static binary undirected network.

Usage

hess_theta_weighted_stat_undir(theta, gamma, N, K)

Arguments

theta

Vector of current theta (network canonical parameters) values.

gamma

Vector of current gamma (variational parameters) values.

N

Number of nodes.

K

Number of clusters.

Value

Returns the Hessian matrix of ELBO with respect to theta parameters for Newton-Raphson update in M-step.


ergmclust documentation built on March 16, 2026, 5:06 p.m.