hess_theta_weighted_stat_undir_K1: C++ function for updating the Hessian matrix in a weighted...

View source: R/RcppExports.R

hess_theta_weighted_stat_undir_K1R Documentation

C++ function for updating the Hessian matrix in a weighted static binary undirected network.

Description

The C++ function hess_theta_weighted_stat_undir_K1() updates the Hessian matrix when the number of clusters is equal to 1 in a weighted static binary undirected network.

Usage

hess_theta_weighted_stat_undir_K1(theta, N)

Arguments

theta

Vector of current theta (network canonical parameters) values.

N

Number of nodes.

Value

Returns the Hessian matrix of ELBO with respect to theta parameters for Newton-Raphson update in M-step.


ergmclust documentation built on March 16, 2026, 5:06 p.m.