rowsum_Mat_new: C++ function for row-wise numeric calculation in a matrix for...

View source: R/RcppExports.R

rowsum_Mat_newR Documentation

C++ function for row-wise numeric calculation in a matrix for a weighted static binary undirected network.

Description

The C++ function rowsum_Mat_new() calculates the sum of each row in a matrix in a weighted static binary undirected network.

Usage

rowsum_Mat_new(M)

Arguments

M

A matrix of numeric type.

Value

Returns a vector as the sum of each row in the input matrix.


ergmclust documentation built on March 16, 2026, 5:06 p.m.