rowsum_dir_Mat: C++ function for row-wise numeric calculation in a matrix for...

View source: R/RcppExports.R

rowsum_dir_MatR Documentation

C++ function for row-wise numeric calculation in a matrix for a static binary directed network.

Description

The C++ function rowsum_dir_Mat() calculates the sum of each row in a matrix in a static binary directed network.

Usage

rowsum_dir_Mat(M)

Arguments

M

A matrix of numeric type.

Value

Returns a vector as the sum of each row in the input matrix.


ergmclust documentation built on March 16, 2026, 5:06 p.m.