tradenet: International Trade Network Data in 1991.

tradenetR Documentation

International Trade Network Data in 1991.

Description

The undirected network on all trade relations internationally among 58 countries. We define the edges as y_{ij}=1, if there is a bilateral trade between country i and j, and y_{ij}=0 otherwise.

Usage

data(tradenet)

Format

The format is a 58 \times 58 network adjacency matrix.

https://projecteuclid.org/euclid.aoas/1310562208#supplemental

References

Westveld, A. H. and Hoff, P. D. (2011) A mixed effects model for longitudinal relational and network data, with applications to international trade and conflict, The Annals of Applied Statistics 5(2A), 843–872

https://projecteuclid.org/euclid.aoas/1310562208

Examples

data(tradenet)

ergmclust documentation built on March 16, 2026, 5:06 p.m.