| wrapper_weighted_stat_undir | R Documentation |
The inner wrapper function wrapper_weighted_stat_undir() is an estimation framework for weighted binary static undirected network based on variational Expectation-Maximization algorithm.
wrapper_weighted_stat_undir(adjmat = NULL, wtmat = NULL, K,
thresh = 10^(-6), iter.max, coef.init)
adjmat |
Array of the network adjacency matrices. |
wtmat |
Array of the network weight matrices. |
K |
Number of clusters for which the estimation must be performed. |
thresh |
Convergence threshold for estimation, the default being 1e-6. |
iter.max |
The maximum number of iterations after which the algorithm is terminated. The default value is set as 200. |
coef.init |
The initial value of the density, stability, transitivity parameters for which clustering is desired, the default being 1e-1. |
Returns a list of ergmclust object. Each object of class ergmclust is a list with the following components:
Converged Parameters |
The first elements of the list in sequential order are gamma, alpha, pi, tau, theta for dynamic networks. For static networks, there is no pi or tau. |
Estimated Cluster IDs |
The second element of the list is a vector (matrix) of estimated cluster memberships for a static (dynamic) case. This is absent for all K=1 cases. |
ICL Values |
The third element of the list is the Integrated Classification Likelihood value that can be used for model selection, i.e. selecting the appropriate number of clusters. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.