| ELBO_conv_weighted_stat_undir_K1 | R Documentation |
The C++ function ELBO_conv_weighted_stat_undir() updates the ELBO convergence function when the number of clusters is 1 in a weighted static binary undirected network.
ELBO_conv_weighted_stat_undir_K1(theta, block_dens_mat, adjmat, N)
theta |
Vector of current |
block_dens_mat |
Array of a network block density matrices. |
adjmat |
Array of a network adjacency matrices. |
N |
Number of nodes. |
Returns the value of ELBO for calculating relative error from the previous iterate that is subsequently used in the stopping criteria of the algorithm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.