| colsum_Mat_new | R Documentation |
The C++ function colsum_Mat_new() calculates the sum of each column in a matrix in a weighted static binary undirected network.
colsum_Mat_new(M)
M |
A matrix of numeric type. |
Returns a vector as the sum of each column in the input matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.