| epan | R Documentation |
The C++ function epan() does numeric calculation depending on the absolute value of the input. If the absolute value of the input is less than or equal to 1, a numeric output is returned. Otherwise, 0 is returned.
epan(input)
input |
A numeric input of float type. |
Returns a float output vector as 0.75*(1-input^2) if the absolute value of the input is less than or equal to 1; 0 otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.